@@ -58,25 +58,6 @@ float ApplicationTools::terminalSplit = 0.5;
 bool ApplicationTools::interactive = true;
 int ApplicationTools::warningLevel = 0;
 
-/******************************************************************************/
-
-bool ApplicationTools::parameterExists(
-  const std::string & parameterName,
-  std::map<std::string, std::string>& params)
-{
-  return (params.find(parameterName) != params.end() && !TextTools::isEmpty(params[parameterName]));
-}
-
-bool ApplicationTools::parameterExists(
-  const std::string & parameterName,
-  std::vector<std::string>& params)
-{
-  for (size_t i = 0; i < params.size(); ++i)
-    if (params[i] == parameterName)
-      return true;
-
-  return false;
-}
 
 /******************************************************************************/
   
@@ -224,26 +205,6 @@ int ApplicationTools::getIntParameter(
 
 /******************************************************************************/
 
-std::string ApplicationTools::getStringParameter(
-  const std::string& parameterName,
-  std::map<std::string, std::string>& params,
-  const std::string& defaultValue,
-  const std::string& suffix,
-  bool suffixIsOptional,
-  int warn)
-{
-  string sParam = defaultValue;
-  if (parameterExists(parameterName + suffix, params)) {
-    sParam = params[parameterName + suffix];
-  } else if (suffixIsOptional && parameterExists(parameterName, params)) {
-    sParam = params[parameterName];
-  } else if (warn <= warningLevel) {
-    displayWarning("Parameter " + parameterName + " not specified. Default used instead: " + defaultValue);
-  }
-  return sParam;
-}
-
-/******************************************************************************/
 
 bool ApplicationTools::getBooleanParameter(
   const std::string& parameterName,
