@@ -80,7 +80,12 @@ class AbstractParametrizable:
     {
       return parameters_.getParameter(prefix_ + name);
     }
-  
+
+  const std::shared_ptr<Parameter>& getSharedParameter(const std::string& name) const throw (ParameterNotFoundException)
+  {
+    return parameters_.getSharedParameter(prefix_ + name);
+  }
+
     double getParameterValue(const std::string& name) const
       throw (ParameterNotFoundException)
     { 
@@ -111,7 +116,7 @@ class AbstractParametrizable:
     bool matchParametersValues(const ParameterList& parameters)
       throw (ConstraintException)
     {
-      std::auto_ptr< std::vector<size_t> >updatedParameters(new std::vector<size_t>());
+      std::unique_ptr< std::vector<size_t> >updatedParameters(new std::vector<size_t>());
       bool test = parameters_.matchParametersValues(parameters, updatedParameters.get());
       if (test) 
         fireParameterChanged(parameters.subList(*updatedParameters));
@@ -131,41 +136,60 @@ class AbstractParametrizable:
      *
      * @param parameters A ParameterList object with parameters that changed.
      */
-    virtual void fireParameterChanged(const ParameterList& parameters) = 0;
+  
+  virtual void fireParameterChanged(const ParameterList& parameters) {};
+  
+  
 
   protected:
-    void addParameter_(Parameter* parameter)
-    {
-      if (parameter)
-        parameters_.addParameter(parameter);
-    }
+  
+  virtual void addParameter_(Parameter* parameter)
+  {
+    if (parameter)
+      parameters_.addParameter(parameter);
+  }
+  
+  virtual void addParameters_(const ParameterList& parameters)
+  {
+    parameters_.addParameters(parameters);
+  }
 
-    void addParameters_(const ParameterList& parameters)
-    {
-      parameters_.addParameters(parameters);
-    }
+  void shareParameter_(const std::shared_ptr<Parameter>& parameter)
+  {
+    parameters_.shareParameter(parameter);
+  }
 
-  void deleteParameter_(size_t index) throw (IndexOutOfBoundsException)
-    {
-      if (index >= parameters_.size())
-        throw IndexOutOfBoundsException("AbstractParametrizable::deleteParameter_.", index, 0, parameters_.size() - 1);
-      parameters_.deleteParameter(index);
-    }
+  void shareParameters_(const ParameterList& parameters)
+  {
+    parameters_.shareParameters(parameters);
+  }
 
-  void deleteParameter_(std::string& name)
+  virtual void includeParameters_(const ParameterList& parameters)
+  {
+    parameters_.includeParameters(parameters);
+  }
+
+  virtual void deleteParameter_(size_t index) throw (IndexOutOfBoundsException)
+  {
+    if (index >= parameters_.size())
+      throw IndexOutOfBoundsException("AbstractParametrizable::deleteParameter_.", index, 0, parameters_.size() - 1);
+    parameters_.deleteParameter(index);
+  }
+
+  virtual void deleteParameter_(std::string& name)
   {
     parameters_.deleteParameter(name);
   }
 
-  void deleteParameters_(const std::vector<std::string>& names)
+  virtual void deleteParameters_(const std::vector<std::string>& names)
   {
      parameters_.deleteParameters(names);
   }
 
-    void resetParameters_()
-    {
-      parameters_.reset();
-    }
+  void resetParameters_()
+  {
+    parameters_.reset();
+  }
 
     /**
      * @param name The name of the parameter.
@@ -202,14 +226,31 @@ class AbstractParametrizable:
         throw IndexOutOfBoundsException("AbstractParametrizable::getParameter_.", index, 0, parameters_.size() - 1);
       return parameters_[index];
     }
-    const Parameter& getParameter_(size_t index) const throw (IndexOutOfBoundsException)
+
+  const Parameter& getParameter_(size_t index) const throw (IndexOutOfBoundsException)
     {
       if(index >= parameters_.size())
         throw IndexOutOfBoundsException("AbstractParametrizable::getParameter_.", index, 0, parameters_.size() - 1);
       return parameters_[index];
     }
-    
-    ParameterList& getParameters_() { return parameters_; }
+
+
+  ParameterList& getParameters_() { return parameters_; }
+
+  /**
+   * @return The shared_ptr parameter at a given position.
+   * @warning No check is performed on the validity of the index given as input!
+   */ 
+  const std::shared_ptr<Parameter>& getSharedParameter(size_t i) const
+  {
+    return parameters_.getSharedParameter(i);
+  }
+  
+  std::shared_ptr<Parameter>& getSharedParameter(size_t i)
+  {
+    return parameters_.getSharedParameter(i);
+  }
+
 };
 
 } //end of namespace bpp.
