@@ -49,12 +49,14 @@ LogsumHmmLikelihood::LogsumHmmLikelihood(
     HmmStateAlphabet* hiddenAlphabet,
     HmmTransitionMatrix* transitionMatrix,
     HmmEmissionProbabilities* emissionProbabilities,
+    bool ownsPointers,
     const std::string& prefix) throw (Exception):
   AbstractHmmLikelihood(),
   AbstractParametrizable(prefix),
   hiddenAlphabet_(hiddenAlphabet),
   transitionMatrix_(transitionMatrix),
   emissionProbabilities_(emissionProbabilities),
+  ownsPointers_(ownsPointers),
   logLikelihood_(),
   partialLogLikelihoods_(),
   logLik_(),
@@ -71,9 +73,10 @@ LogsumHmmLikelihood::LogsumHmmLikelihood(
   if (!hiddenAlphabet)        throw Exception("LogsumHmmLikelihood: null pointer passed for HmmStateAlphabet.");
   if (!transitionMatrix)      throw Exception("LogsumHmmLikelihood: null pointer passed for HmmTransitionMatrix.");
   if (!emissionProbabilities) throw Exception("LogsumHmmLikelihood: null pointer passed for HmmEmissionProbabilities.");
-  if (!hiddenAlphabet_->worksWith(transitionMatrix->getHmmStateAlphabet()))
+
+  if (!hiddenAlphabet_->worksWith(transitionMatrix_->getHmmStateAlphabet()))
     throw Exception("LogsumHmmLikelihood: HmmTransitionMatrix and HmmEmissionProbabilities should point toward the same HmmStateAlphabet object.");
-  if (!hiddenAlphabet_->worksWith(emissionProbabilities->getHmmStateAlphabet()))
+  if (!hiddenAlphabet_->worksWith(emissionProbabilities_->getHmmStateAlphabet()))
     throw Exception("LogsumHmmLikelihood: HmmTransitionMatrix and HmmEmissionProbabilities should point toward the same HmmStateAlphabet object.");
   nbStates_ = hiddenAlphabet_->getNumberOfStates();
   nbSites_ = emissionProbabilities_->getNumberOfPositions();
@@ -85,11 +88,20 @@ LogsumHmmLikelihood::LogsumHmmLikelihood(
 
   //Init arrays:
   logLikelihood_.resize(nbSites_ * nbStates_);
-  
+
   //Compute:
   computeForward_();
 }
 
+void LogsumHmmLikelihood::setNamespace(const std::string& nameSpace)
+{
+  AbstractParametrizable::setNamespace(nameSpace);
+
+  hiddenAlphabet_->setNamespace(nameSpace);
+  transitionMatrix_->setNamespace(nameSpace);
+  emissionProbabilities_->setNamespace(nameSpace);
+}
+
 void LogsumHmmLikelihood::fireParameterChanged(const ParameterList& pl)
 {
   dVariable_="";
@@ -103,9 +115,14 @@ void LogsumHmmLikelihood::fireParameterChanged(const ParameterList& pl)
   // (when both the alphabet and other parameter changed).
   if (alphabetChanged && !transitionsChanged) transitionMatrix_->setParametersValues(transitionMatrix_->getParameters());
   if (alphabetChanged && !emissionChanged) emissionProbabilities_->setParametersValues(emissionProbabilities_->getParameters());
-  
-  computeForward_();
+
   backLogLikelihoodUpToDate_=false;
+  computeLikelihood();
+}
+
+void LogsumHmmLikelihood::computeLikelihood()
+{
+  computeForward_();
 }
 
 /***************************************************************************************************************************/
@@ -124,18 +141,19 @@ void LogsumHmmLikelihood::computeForward_()
   }
 
   //Initialisation:
-  const vector<double>* emissions = &(*emissionProbabilities_)(0);
-  
+  const vector<double>* emissions = &(* emissionProbabilities_)(0);
+
   for (size_t j = 0; j < nbStates_; j++)
   {
     size_t jj = j * nbStates_;
     x = logTrans[jj] + log(transitionMatrix_->getEquilibriumFrequencies()[0]);
-    
+
     for (size_t k = 1; k < nbStates_; k++)
     {
       a = logTrans[k + jj] + log(transitionMatrix_->getEquilibriumFrequencies()[k]);
       x = NumTools::logsum(x, a);
     }
+
     logLikelihood_[j] = log((*emissions)[j]) + x;
   }
  
@@ -374,9 +392,7 @@ void LogsumHmmLikelihood::computeDForward_() const
 
   partialDLogLikelihoods_.clear();
 
-  double x;
-
-  vector<double> num(nbStates_);
+  vector<double> num(nbStates_), num2(nbStates_);
 
   //Transition probabilities:
   const ColMatrix<double> trans(transitionMatrix_->getPij());
@@ -384,7 +400,7 @@ void LogsumHmmLikelihood::computeDForward_() const
   //Initialisation:
   const vector<double>* emissions = &(*emissionProbabilities_)(0);
   const vector<double>* dEmissions = &emissionProbabilities_->getDEmissionProbabilities(0);
-  
+
   for (size_t j = 0; j < nbStates_; j++)
     dLogLikelihood_[0][j] = (*dEmissions)[j] / (*emissions)[j];
 
@@ -401,36 +417,25 @@ void LogsumHmmLikelihood::computeDForward_() const
     emissions = &(*emissionProbabilities_)(i);
     dEmissions = &emissionProbabilities_->getDEmissionProbabilities(i);
 
+    for (size_t kp = 0; kp < nbStates_; kp++)
+      num[kp]=logLikelihood_[iip+kp];
+
+    num-=num[VectorTools::whichMax(num)];
+
     if (i < nextBrkPt)
     {
       for (size_t j = 0; j < nbStates_; j++)
       {
-        x=(*dEmissions)[j]/(*emissions)[j];
+        num2=dLogLikelihood_[i-1]*trans.getCol(j);
 
-        for (size_t k = 0; k < nbStates_; k++)
-        {
-          for (size_t kp = 0; kp < nbStates_; kp++)
-            num[kp]=logLikelihood_[iip+kp]-logLikelihood_[iip+k];
-
-          x+=dLogLikelihood_[i-1][k]*trans(k,j)/VectorTools::sumExp(num,trans.getCol(j));
-        }
-        
-        dLogLikelihood_[i][j] = x;
+        dLogLikelihood_[i][j] = (*dEmissions)[j]/(*emissions)[j] + VectorTools::sumExp(num,num2)/VectorTools::sumExp(num,trans.getCol(j));
       }
     }      
     else //Reset markov chain:
     {
       //Termination of previous segment
-      x = 0;
-      for (size_t k = 0; k < nbStates_; k++)
-      {
-        for (size_t kp = 0; kp < nbStates_; kp++)
-          num[kp]=logLikelihood_[iip+kp]-logLikelihood_[iip+k];
-        
-        x += dLogLikelihood_[i-1][k] / VectorTools::sumExp(num);
-      }
-          
-      partialDLogLikelihoods_.push_back(x);
+
+      partialDLogLikelihoods_.push_back(VectorTools::sumExp(num,dLogLikelihood_[i-1])/VectorTools::sumExp(num));
 
       for (size_t j = 0; j < nbStates_; j++)
         dLogLikelihood_[i][j] = (*dEmissions)[j] / (*emissions)[j];
@@ -444,17 +449,13 @@ void LogsumHmmLikelihood::computeDForward_() const
   }
   
   //Termination:
-  x=0;
-  for (size_t k = 0; k < nbStates_; k++)
-  {
-    for (size_t kp = 0; kp < nbStates_; kp++)
-      num[kp]=logLikelihood_[nbStates_*(nbSites_-1)+kp]-logLikelihood_[nbStates_*(nbSites_-1)+k];
+  for (size_t kp = 0; kp < nbStates_; kp++)
+    num[kp]=logLikelihood_[nbStates_*(nbSites_-1)+kp];
+
+  num-=num[VectorTools::whichMax(num)];
             
-    x += dLogLikelihood_[nbSites_-1][k] / VectorTools::sumExp(num);
-  }
-          
-  partialDLogLikelihoods_.push_back(x);
-  
+  partialDLogLikelihoods_.push_back(VectorTools::sumExp(num,dLogLikelihood_[nbSites_-1])/VectorTools::sumExp(num));
+
   //Compute dLogLikelihood
   
   dLogLik_ = 0;
@@ -464,6 +465,11 @@ void LogsumHmmLikelihood::computeDForward_() const
     dLogLik_ += copy[i - 1];
 }
 
+double LogsumHmmLikelihood::getDLogLikelihoodForASite(size_t site) const
+{
+  return partialDLogLikelihoods_[site];
+}
+
 /***************************************************************************************************************************/
 
 void LogsumHmmLikelihood::computeD2Forward_() const
@@ -480,9 +486,7 @@ void LogsumHmmLikelihood::computeD2Forward_() const
 
   partialD2LogLikelihoods_.clear();
   
-  double x, z, snum;
-
-  vector<double> num(nbStates_);
+  vector<double> num(nbStates_),num2(nbStates_),num3(nbStates_);
   
   //Transition probabilities:
   const ColMatrix<double> trans(transitionMatrix_->getPij());
@@ -509,45 +513,33 @@ void LogsumHmmLikelihood::computeD2Forward_() const
     dEmissions = &emissionProbabilities_->getDEmissionProbabilities(i);
     d2Emissions = &emissionProbabilities_->getD2EmissionProbabilities(i);
 
+    for (size_t kp = 0; kp < nbStates_; kp++)
+      num[kp]=logLikelihood_[iip+kp];
+
+    num-=num[VectorTools::whichMax(num)];
+
     if (i < nextBrkPt)
     {
       for (size_t j = 0; j < nbStates_; j++)
       {
-        x=(*d2Emissions)[j] / (*emissions)[j] - pow((*dEmissions)[j] / (*emissions)[j],2);
+        double den=VectorTools::sumExp(num,trans.getCol(j));
 
-        for (size_t k = 0; k < nbStates_; k++)
-        {
-          for (size_t kp = 0; kp < nbStates_; kp++)
-            num[kp]=logLikelihood_[iip+kp]-logLikelihood_[iip+k];
-          snum=VectorTools::sumExp(num,trans.getCol(j));
+        num2=dLogLikelihood_[i-1]*trans.getCol(j);
 
-          
-          z=d2LogLikelihood_[i-1][k]+pow(dLogLikelihood_[i-1][k],2)
-            - dLogLikelihood_[i-1][k] * VectorTools::sumExp(num, trans.getCol(j) * dLogLikelihood_[i-1])/snum;
+        num3=(dLogLikelihood_[i-1]*dLogLikelihood_[i-1]+d2LogLikelihood_[i-1])*trans.getCol(j);
 
-          x += z * trans(k,j) / snum;
-        }
-
-        d2LogLikelihood_[i][j] = x;
+        d2LogLikelihood_[i][j] =  VectorTools::sumExp(num,num3)/den - pow(VectorTools::sumExp(num,num2)/den,2);
       }
     }
     else //Reset markov chain:
     {
-      x=0;
-      
       //Termination of previous segment:
-      for (size_t k = 1; k < nbStates_; k++)
-      {
-        for (size_t kp = 0; kp < nbStates_; kp++)
-          num[kp]=logLikelihood_[iip+kp]-logLikelihood_[iip+k];
-        
-        snum=VectorTools::sumExp(num);
-        
-        x += (d2LogLikelihood_[i-1][k]+pow(dLogLikelihood_[i-1][k],2)
-              - dLogLikelihood_[i-1][k] * VectorTools::sumExp(num, dLogLikelihood_[i-1])/snum)/snum;
-      }
-      
-      partialD2LogLikelihoods_.push_back(x);
+
+      double den=VectorTools::sumExp(num);
+
+      num2=dLogLikelihood_[i-1]*dLogLikelihood_[i-1]+d2LogLikelihood_[i-1];
+
+      partialD2LogLikelihoods_.push_back(VectorTools::sumExp(num,num2)/den-pow(VectorTools::sumExp(num,dLogLikelihood_[i-1])/den,2));
       
       for (size_t j = 0; j < nbStates_; j++)
         d2LogLikelihood_[i][j] = (*d2Emissions)[j] / (*emissions)[j] - pow((*dEmissions)[j] / (*emissions)[j],2);
@@ -560,21 +552,19 @@ void LogsumHmmLikelihood::computeD2Forward_() const
   }  
 
   //Termination:
-  x=0;
-  for (size_t k = 0; k < nbStates_; k++)
-  {
-    for (size_t kp = 0; kp < nbStates_; kp++)
-      num[kp]=logLikelihood_[nbStates_*(nbSites_-1)+kp]-logLikelihood_[nbStates_*(nbSites_-1)+k];
-    
-    snum=VectorTools::sumExp(num);
-    
-    x += (d2LogLikelihood_[nbSites_-1][k]+pow(dLogLikelihood_[nbSites_-1][k],2)
-          - dLogLikelihood_[nbSites_-1][k] * VectorTools::sumExp(num, dLogLikelihood_[nbSites_-1])/snum)/snum;
-  }
+  for (size_t kp = 0; kp < nbStates_; kp++)
+    num[kp]=logLikelihood_[nbStates_*(nbSites_-1)+kp];
+
+  num-=num[VectorTools::whichMax(num)];
+
+  double den=VectorTools::sumExp(num);
+
+  num2=dLogLikelihood_[nbSites_-1]*dLogLikelihood_[nbSites_-1]+d2LogLikelihood_[nbSites_-1];
+
+  partialD2LogLikelihoods_.push_back(VectorTools::sumExp(num,num2)/den-pow(VectorTools::sumExp(num,dLogLikelihood_[nbSites_-1])/den,2));
 
-  partialD2LogLikelihoods_.push_back(x);
   
-  //Compute dLogLikelihood
+  //Compute d2LogLikelihood
   
   d2LogLik_ = 0;
   vector<double> copy = partialD2LogLikelihoods_; //We need to keep the original order for posterior decoding.
@@ -582,3 +572,8 @@ void LogsumHmmLikelihood::computeD2Forward_() const
   for (size_t i = copy.size(); i > 0; --i)
     d2LogLik_ += copy[i - 1];
 }
+
+double LogsumHmmLikelihood::getD2LogLikelihoodForASite(size_t site) const
+{
+  return partialD2LogLikelihoods_[site];
+}
