@@ -79,6 +79,11 @@ typedef std::vector<Vint> VVint;
 typedef std::vector<VVint> VVVint;
 typedef std::vector<VVVint> VVVVint;
 
+typedef std::vector<unsigned int> Vuint;
+typedef std::vector<Vint> VVuint;
+typedef std::vector<VVint> VVVuint;
+typedef std::vector<VVVint> VVVVuint;
+
 /**
  * @name Element-wise operations.
  * @{
@@ -286,6 +291,14 @@ void operator/=(std::vector<T>& v1, const std::vector<T>& v2) throw (DimensionEx
   }
 }
 
+template<class T, class C>
+void operator&=(std::vector<T>& v1, const C& c)
+{
+  for (size_t i = 0; i < v1.size(); i++)
+  {
+    v1[i] = c;
+  }
+}
 
 template<class T, class C>
 void operator+=(std::vector<T>& v1, const C& c)
@@ -660,6 +673,9 @@ public:
   static T logSumExp(const std::vector<T>& v1)
   {
     T M = max(v1);
+    if (std::isinf(M))
+      return M;
+    
     T x = std::exp(v1[0] - M);
     for (size_t i = 1; i < v1.size(); i++)
     {
@@ -684,6 +700,9 @@ public:
       size = v1.size();
 
     T M = max(v1);
+    if (std::isinf(M))
+      throw BadNumberException("VectorTools::logSumExp", M);
+    
     T x = v2[0] * std::exp(v1[0] - M);
     for (size_t i = 1; i < size; i++)
     {
@@ -701,6 +720,9 @@ public:
   static T logMeanExp(const std::vector<T>& v1)
   {
     T M = max(v1);
+    if (std::isinf(M))
+      return M;
+
     T x = std::exp(v1[0] - M);
     for (size_t i = 1; i < v1.size(); i++)
     {
@@ -719,6 +741,9 @@ public:
   static T sumExp(const std::vector<T>& v1)
   {
     T M = max(v1);
+    if (std::isinf(M))
+      return (M<0?0:M);
+
     T x = std::exp(v1[0] - M);
     for (size_t i = 1; i < v1.size(); i++)
     {
@@ -738,11 +763,14 @@ public:
   {
     size_t size;
     if (v1.size() != v2.size())
-      throw DimensionException("VectorTools::logsumexp", v1.size(), v2.size());
+      throw DimensionException("VectorTools::sumExp", v1.size(), v2.size());
     else
       size = v1.size();
 
     T M = max(v1);
+    if (std::isinf(M))
+      throw BadNumberException("VectorTools::sumExp", M);
+
     T x = v2[0] * std::exp(v1[0] - M);
     for (size_t i = 1; i < size; i++)
     {
@@ -757,13 +785,21 @@ public:
    *
    * @{
    */
+  
   template<class T>
-  static std::vector<double> log(const std::vector<T>& v1)
+  static std::vector<T> log(const std::vector<T>& v1)
   {
-    std::vector<double> v2(v1.size());
-    for (size_t i = 0; i < v2.size(); i++) { v2[i] = std::log(v1[i]); }
+    std::vector<T> v2(v1.size());
+    for (size_t i = 0; i < v2.size(); i++) { v2[i] = VectorTools::log(v1[i]); }
     return v2;
   }
+
+  template<class T>
+  static double log(const T& x)
+  {
+    return std::log(x);
+  }
+  
   template<class T>
   static std::vector<double> log(const std::vector<T>& v1, double base)
   {
@@ -773,10 +809,16 @@ public:
   }
 
   template<class T>
-  static std::vector<double> exp(const std::vector<T>& v1)
+  static double exp(const T& x)
   {
-    std::vector<double> v2(v1.size());
-    for (size_t i = 0; i < v2.size(); i++) { v2[i] = std::exp(v1[i]); }
+    return std::exp(x);
+  }
+
+  template<class T>
+  static std::vector<T> exp(const std::vector<T>& v1)
+  {
+    std::vector<T> v2(v1.size());
+    for (size_t i = 0; i < v2.size(); i++) { v2[i] = VectorTools::exp(v1[i]); }
     return v2;
   }
 
@@ -867,6 +909,31 @@ public:
     out.endLine();
   }
 
+  template<class T>
+  static void printRange(const std::vector<T>& v1, OutputStream& out = * ApplicationTools::message, const std::string& delim = ",", const std::string& rangeDelim = "-")
+  {
+    size_t vs=v1.size();
+    
+    for (size_t i = 0; i < vs; i++)
+    {
+      out << v1[i];
+      size_t j=i+1;
+      
+      while (j<vs)
+        if (v1[j]==v1[j-1]+1)
+          j++;
+        else
+          break;
+      
+      if (j>i+2)
+        out << rangeDelim << v1[j-1];
+      i=j-1;
+      if (i<vs-1)
+        out << delim;
+    }
+  }
+
+
   /**
    * @brief Print a std::vector to a stream in R format
    * @param v1 A std::vector.
@@ -898,7 +965,7 @@ public:
   {
     if (v1.size() != v2.size())
     {
-      throw DimensionException("VectorFunctions::scalar", v1.size(), v2.size());
+      throw DimensionException("VectorTools::scalar", v1.size(), v2.size());
     }
     OutputType result = 0;
     for (size_t i = 0; i < v1.size(); i++)
@@ -928,11 +995,11 @@ public:
   {
     if (v1.size() != w.size())
     {
-      throw DimensionException("VectorFunctions::scalar", v1.size(), w.size());
+      throw DimensionException("VectorTools::scalar", v1.size(), w.size());
     }
     if (v2.size() != w.size())
     {
-      throw DimensionException("VectorFunctions::scalar", v2.size(), w.size());
+      throw DimensionException("VectorTools::scalar", v2.size(), w.size());
     }
     OutputType result = 0;
     for (size_t i = 0; i < v1.size(); i++)
@@ -992,7 +1059,7 @@ public:
   {
     if (v1.size() != w.size())
     {
-      throw DimensionException("VectorFunctions::norm", v1.size(), w.size());
+      throw DimensionException("VectorTools::norm", v1.size(), w.size());
     }
     OutputType result = 0;
     for (size_t i = 0; i < v1.size(); i++)
@@ -1047,7 +1114,7 @@ public:
   template<class T>
   static T min(const std::vector<T>& v) throw (EmptyVectorException<T> )
   {
-    if (v.size() == 0) throw EmptyVectorException<T>("VectorFunctions::min()", &v);
+    if (v.size() == 0) throw EmptyVectorException<T>("VectorTools::min()", &v);
     T mini = v[0];
     for (size_t i = 1; i < v.size(); i++)
     {
@@ -1068,7 +1135,7 @@ public:
   template<class T>
   static T max(const std::vector<T>& v) throw (EmptyVectorException<T> )
   {
-    if (v.size() == 0) throw EmptyVectorException<T>("VectorFuntions::max()", &v);
+    if (v.size() == 0) throw EmptyVectorException<T>("VectorTools::max()", &v);
     T maxi = v[0];
     for (size_t i = 1; i < v.size(); i++)
     {
@@ -1117,7 +1184,7 @@ public:
   template<class T>
   static size_t whichMin(const std::vector<T>& v) throw (EmptyVectorException<T> )
   {
-    if (v.size() == 0) throw EmptyVectorException<T>("VectorFunctions::whichMin()", &v);
+    if (v.size() == 0) throw EmptyVectorException<T>("VectorTools::whichMin()", &v);
     T mini = v[0];
     size_t pos = 0;
     for (size_t i = 1; i < v.size(); i++)
